SlaveTimer3

Struct SlaveTimer3 

pub struct SlaveTimer3 { /* private fields */ }
SHRTIMER Slave TIMER3 registers(

Implementations

Source

impl SlaveTimer3

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn st3ctl0(&self) -> &St3ctl0

0x00 - SHRTIMER Slave_TIMERx control register 0

pub fn st3intf(&self) -> &St3intf

0x04 - SHRTIMER Slave_TIMERx interrupt flag register

pub fn st3intc(&self) -> &St3intc

0x08 - SHRTIMER Slave_TIMERx interrupt flag clear register

pub fn st3dmainten(&self) -> &St3dmainten

0x0c - SHRTIMER Slave_TIMERx DMA and interrupt enable register

pub fn st3cnt(&self) -> &St3cnt

0x10 - SHRTIMER Slave_TIMERx counter register

pub fn st3car(&self) -> &St3car

0x14 - SHRTIMER Slave_TIMER3 counter auto reload register

pub fn st3crep(&self) -> &St3crep

0x18 - SHRTIMER Slave_TIMER3 counter repetition register

pub fn st3cmp0v(&self) -> &St3cmp0v

0x1c - SHRTIMER Slave_TIMER3 compare 0 value register

pub fn st3cmp0cp(&self) -> &St3cmp0cp

0x20 - SHRTIMER Slave_TIMERx compare 0 composite register

pub fn st3cmp1v(&self) -> &St3cmp1v

0x24 - SHRTIMER Slave_TIMERx compare 1 value register

pub fn st3cmp2v(&self) -> &St3cmp2v

0x28 - SHRTIMER Slave_TIMERx compare 2 value register

pub fn st3cmp3v(&self) -> &St3cmp3v

0x2c - SHRTIMER Slave_TIMERx compare 3 value register

pub fn st3cap0v(&self) -> &St3cap0v

0x30 - SHRTIMER Slave_TIMERx capture 0 value register

pub fn st3cap1v(&self) -> &St3cap1v

0x34 - SHRTIMER Slave_TIMERx capture 1 value register

pub fn st3dtctl(&self) -> &St3dtctl

0x38 - SHRTIMER Slave_TIMERx dead-time control register

pub fn st3ch0set(&self) -> &St3ch0set

0x3c - SHRTIMER Slave_TIMERx channel 0 set request register

pub fn st3ch0rst(&self) -> &St3ch0rst

0x40 - SHRTIMER Slave_TIMERx channel 0 reset request register

pub fn st3ch1set(&self) -> &St3ch1set

0x44 - SHRTIMER Slave_TIMERx channel 1 set request register

pub fn st3ch1rst(&self) -> &St3ch1rst

0x48 - SHRTIMER Slave_TIMERx channel 1 reset request register

pub fn st3exevfcfg0(&self) -> &St3exevfcfg0

0x4c - SHRTIMER Slave_TIMERx external event filter configuration register 0

pub fn st3exevfcfg1(&self) -> &St3exevfcfg1

0x50 - SHRTIMER Slave_TIMERx external event filter configuration register 1

pub fn st3cntrst(&self) -> &St3cntrst

0x54 - SHRTIMER Slave_TIMERx counter reset register

pub fn st3csctl(&self) -> &St3csctl

0x58 - SHRTIMER Slave_TIMERx carrier-signal control register

pub fn st3cap0trg(&self) -> &St3cap0trg

0x5c - SHRTIMER Slave_TIMERx capture 0 trigger register

pub fn st3cap1trg(&self) -> &St3cap1trg

0x60 - SHRTIMER Slave_TIMERx capture 1 trigger register

pub fn st3choctl(&self) -> &St3choctl

0x64 - SHRTIMER Slave_TIMERx channel output control register

pub fn st3fltctl(&self) -> &St3fltctl

0x68 - SHRTIMER Slave_TIMERx fault control register

pub fn st3actl(&self) -> &St3actl

0x7c - SHRTIMER Slave_TIMERx additional control register