ShrtimerCommon

Struct ShrtimerCommon 

pub struct ShrtimerCommon { /* private fields */ }
SHRTIMER Common registers

Implementations

Source

impl ShrtimerCommon

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn ctl0(&self) -> &Ctl0

0x00 - SHRTIMER control register 0

pub fn ctl1(&self) -> &Ctl1

0x04 - SHRTIMER control register 1

pub fn intf(&self) -> &Intf

0x08 - SHRTIMER interrupt flag register

pub fn intc(&self) -> &Intc

0x0c - SHRTIMER interrupt flag clear register

pub fn inten(&self) -> &Inten

0x10 - SHRTIMER interrupt enable register

pub fn chouten(&self) -> &Chouten

0x14 - SHRTIMER channel output enable register

pub fn choutdis(&self) -> &Choutdis

0x18 - SHRTIMER channel output disable register

pub fn choutdisf(&self) -> &Choutdisf

0x1c - SHRTIMER channel output disable flag register

pub fn bmctl(&self) -> &Bmctl

0x20 - SHRTIMER bunch mode control register

pub fn bmstrg(&self) -> &Bmstrg

0x24 - SHRTIMER bunch mode start trigger register

pub fn bmcmpv(&self) -> &Bmcmpv

0x28 - SHRTIMER bunch mode compare value register

pub fn bmcar(&self) -> &Bmcar

0x2c - SHRTIMER bunch mode counter auto reload register

pub fn exevcfg0(&self) -> &Exevcfg0

0x30 - SHRTIMER external event configuration register 0

pub fn exevcfg1(&self) -> &Exevcfg1

0x34 - SHRTIMER external event configuration register 1

pub fn exevdfctl(&self) -> &Exevdfctl

0x38 - SHRTIMER external event digital filter control register

pub fn adctrigs0(&self) -> &Adctrigs0

0x3c - SHRTIMER trigger source 0 to ADC register

pub fn adctrigs1(&self) -> &Adctrigs1

0x40 - SHRTIMER trigger source 1 to ADC register

pub fn adctrigs2(&self) -> &Adctrigs2

0x44 - SHRTIMER trigger source 2 to ADC register

pub fn adctrigs3(&self) -> &Adctrigs3

0x48 - SHRTIMER trigger source 3 to ADC register

pub fn dllcctl(&self) -> &Dllcctl

0x4c - SHRTIMER DLL calibration control register

pub fn fltincfg0(&self) -> &Fltincfg0

0x50 - SHRTIMER fault input configuration register 0

pub fn fltincfg1(&self) -> &Fltincfg1

0x54 - SHRTIMER fault input configuration register 1

pub fn dmaupmtr(&self) -> &Dmaupmtr

0x58 - SHRTIMER DMA update Master_TIMER register

pub fn dmaupst0r(&self) -> &Dmaupst0r

0x5c - SHRTIMER DMA update Slave_TIMER0 register

pub fn dmaupst1r(&self) -> &Dmaupst1r

0x60 - SHRTIMER DMA update Slave_TIMER1 register

pub fn dmaupst2r(&self) -> &Dmaupst2r

0x64 - SHRTIMER DMA update Slave_TIMER2 register

pub fn dmaupst3r(&self) -> &Dmaupst3r

0x68 - SHRTIMER DMA update Slave_TIMER3 register

pub fn dmaupst4r(&self) -> &Dmaupst4r

0x6c - SHRTIMER DMA update Slave_TIMER4 register

pub fn dmatb(&self) -> &Dmatb

0x70 - SHRTIMER DMA transfer buffer register