Timer5

Struct Timer5 

pub struct Timer5 { /* private fields */ }
Basic-timers

Implementations

Source

impl Timer5

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn ctl0(&self) -> &Ctl0

0x00 - control register 0

pub fn ctl1(&self) -> &Ctl1

0x04 - control register 1

pub fn dmainten(&self) -> &Dmainten

0x0c - DMA/Interrupt enable register

pub fn intf(&self) -> &Intf

0x10 - Interrupt flag register

pub fn swevg(&self) -> &Swevg

0x14 - event generation register

pub fn cnt(&self) -> &Cnt

0x24 - Counter register

pub fn psc(&self) -> &Psc

0x28 - Prescaler register

pub fn car(&self) -> &Car

0x2c - Counter auto reload register